@@ -4,18 +4,18 @@ use 5.010;
 use strict;
 use warnings;
 use utf8;
-use Template::Tiny 0.11;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use Mouse;
 use MouseX::Types::Path::Class;
 use Path::Class;
+use Try::Tiny;
 use File::Path qw(make_path);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.973';
+our $VERSION = '0.980';
 
 has requires => (
     is       => 'ro',
@@ -53,6 +53,14 @@ has template_directory => (
     isa => 'Maybe[Path::Class::Dir]',
 );
 
+has template_name => (
+    is       => 'ro',
+    isa      => 'Str',
+    required => 1,
+    lazy     => 1,
+    default  => sub { shift->sqitch->_engine },
+);
+
 for my $script (qw(deploy revert verify)) {
     has "with_$script" => (
         is      => 'ro',
@@ -77,6 +85,7 @@ for my $script (qw(deploy revert verify)) {
 sub _find {
     my ( $self, $script ) = @_;
     my $config = $self->sqitch->config;
+    my $name   = $self->template_name;
     $config->get( key => "add.$script\_template" ) || do {
         for my $dir (
             $self->template_directory,
@@ -84,7 +93,7 @@ sub _find {
             $config->system_dir->subdir('templates'),
         ) {
             next unless $dir;
-            my $tmpl = $dir->file("$script.tmpl");
+            my $tmpl = $dir->file($script, "$name.tmpl");
             return $tmpl if -f $tmpl;
         }
         hurl add => __x(
@@ -99,7 +108,7 @@ sub options {
         requires|r=s@
         conflicts|c=s@
         note|n=s@
-        set|s=s%
+        template-name|template|t=s
         template-directory=s
         deploy-template=s
         revert-template=s
@@ -110,6 +119,37 @@ sub options {
     );
 }
 
+# Override to convert multiple vars to an array.
+sub _parse_opts {
+    my ( $class, $args ) = @_;
+    return {} unless $args && @{$args};
+
+    my (%opts, %vars);
+    Getopt::Long::Configure(qw(bundling no_pass_through));
+    Getopt::Long::GetOptionsFromArray(
+        $args, \%opts,
+        $class->options,
+        'set|s=s%' => sub {
+            my ($opt, $key, $val) = @_;
+            if (exists $vars{$key}) {
+                $vars{$key} = [$vars{$key}] unless ref $vars{$key};
+                push @{ $vars{$key} } => $val;
+            } else {
+                $vars{$key} = $val;
+            }
+        }
+    ) or $class->usage;
+
+    # Convert dashes to underscores.
+    for my $k (keys %opts) {
+        next unless ( my $nk = $k ) =~ s/-/_/g;
+        $opts{$nk} = delete $opts{$k};
+    }
+
+    $opts{set} = \%vars if %vars;
+    return \%opts;
+}
+
 sub configure {
     my ( $class, $config, $opt ) = @_;
 
@@ -121,7 +161,7 @@ sub configure {
 
     if (
         my $dir = $opt->{template_directory}
-               || $config->get( key => "add.template_directory" )
+            || $config->get( key => 'add.template_directory' )
     ) {
         $dir = $params{template_directory} = dir $dir;
         hurl add => __x(
@@ -136,6 +176,13 @@ sub configure {
 
     }
 
+    if (
+        my $name = $opt->{template_name}
+            || $config->get( key => 'add.template_name' )
+    ) {
+        $params{template_name} = $name;
+    }
+
     for my $attr (qw(deploy revert verify)) {
         $params{"with_$attr"} = $opt->{$attr} if exists $opt->{$attr};
         my $t = "$attr\_template";
@@ -143,7 +190,6 @@ sub configure {
     }
 
     if ( my $vars = $opt->{set} ) {
-
         # Merge with config.
         $params{variables} = {
             %{ $config->get_section( section => 'add.variables' ) },
@@ -226,27 +272,33 @@ sub _add {
         hurl add => $msg;
     }
 
+    my $vars = {
+        %{ $self->variables },
+        change    => $name,
+        requires  => $self->requires,
+        conflicts => $self->conflicts,
+    };
+
     my $fh = $file->open('>:utf8_strict') or hurl add => __x(
         'Cannot open {file}: {error}',
         file  => $file,
         error => $!
     );
-    my $orig_selected = select;
-    select $fh;
 
-    Template::Tiny->new->process( $self->_slurp($tmpl), {
-        %{ $self->variables },
-        change    => $name,
-        requires  => $self->requires,
-        conflicts => $self->conflicts,
-    });
+    if (eval 'use Template; 1') {
+        Template->new->process( $self->_slurp($tmpl), $vars, $fh );
+    } else {
+        eval 'use Template::Tiny 0.11; 1' or die $@;
+        my $output = '';
+        Template::Tiny->new->process( $self->_slurp($tmpl), $vars, \$output );
+        print $fh $output;
+    }
 
     close $fh or hurl add => __x(
         'Error closing {file}: {error}',
         file  => $file,
         error => $!
     );
-    select $orig_selected;
     $self->info(__x 'Created {file}', file => $file);
 }
 
